@@ -1,5 +1,5 @@
 from collections import defaultdict
-from typing import Any, DefaultDict, Dict, Optional, Set
+from typing import Any, DefaultDict, Dict, List, Optional, Set
 
 from pydantic import BaseModel, validator
 
@@ -25,6 +25,7 @@ class BaseLoggerConfig(BaseModel):
     helper_data: Dict[str, Any] = {}
     input_data_logged: DefaultDict[str, int] = defaultdict(int)
     logged_input_ids: DefaultDict[str, Set] = defaultdict(set)
+    idx_to_id_map: DefaultDict[str, List] = defaultdict(list)
 
     class Config:
         validate_assignment = True
